%commit = (
  "0ae36f101c68fd82a5bb9845fdf99e3fc6ab369e" => {
    body => "",
    extra => "",
    parent => [
      "9be9b53c65ebf7c4f9d6de843619fd0990fb8d43",
      "88df96b38e9861eab3af30a312d24a740f3defd2"
    ],
    subject => "Merge branch 'slave'",
    tree => "fa85af1dc631f3f8d977aafe0253b1d02eb2c4c7"
  },
  "21a06f684ba48bdff19436074f991267c849afcf" => {
    body => "signed tag\n\n# gpg: Signature made Tue Nov  5 06:32:38 2013 CET using RSA key ID 7621C403\n# gpg: Good signature from \"Example Author <author\@example.com>\"\n",
    extra => "",
    mergetag => [
      "object f7c18a39ec24778012af208988bc23e6f1f3a636\ntype commit\ntag v1.0.0\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL2AAoJEOX2RRt2IcQDUBsIAKlseVblr9McHXa1Yt6k4pbr\nKfjwUEpVSpOoeTVCUbr5etrhFA7k7eUYVo0NtEyHZGpvKOHDPBvwjiQ2BWDXqGsA\nPXwGJEUQ/BV1vLoj2lF/VuZQ53Lr1JH49tjxDvC5jzVwLl5TTQVOm6zCS9GVmoT4\ninmDmQk6BKmFqFP4f2TxANXYuiOBKLPGKRdEEZ0PvodLhQEJ6tCIGjZjxx8qUH6e\ndcBj0DOQ/pdBKSls9NnWAsGhoDefILR1m3n1zd6aFBtIlhfT5HY4ZA9RQAjvXeL3\nU7LSjUPGoygsSUkISSrIDypGqlO1Dwt8bLP4gtrxu54D/YDQzp2lEXxMtY/297U=\n=tizV\n-----END PGP SIGNATURE-----"
    ],
    parent => [
      "dd8437af8d1fa7c53de33db969ceceee8c1c153a",
      "f7c18a39ec24778012af208988bc23e6f1f3a636"
    ],
    subject => "Merge tag 'v1.0.0'",
    tree => "7b8f01341e59251bbf067b1001cdd12f44c36847"
  },
  "3eee6394377f62106ddd207b68942676da1b18ea" => {
    body => "",
    extra => "",
    mergetag => [
      "object 7fa20ca61711a0109d431b1a479e3091c8ac9317\ntype commit\ntag v1.0.1\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\n\303\243\302\201\302\223\303\243\302\202\302\223\303\243\302\201\302\253\303\243\302\201\302\241\303\243\302\201\302\257\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL2AAoJEOX2RRt2IcQDVAcH/2gaHSXfEgOuvB5S66JWNTMT\n4rqAJkFzaWUgT8F/ofou5O958n5bTjla1YHn93Cm+JCrJk53ECZR1lH0u8H5tRQK\nAQbKO/5HCHh9vh8/G4gghL62a8BwBU5wGwujZdFjtJOmix/2/80QuP5dY7zB1p2j\n0g024ZOaDvv70YAbFQibzZNH/I4LQK0gB2NamVZmcrWI/YWH8LVdVJrzkGFMne/r\n5F5B+kOXZp7KDCdbToNMT2NG5KAT6nkyCWv6njcehiL85V73hpBLy/HD1FAHeGFD\nzru/CXmrEejKRXoz8F7QBx8z2uQ4PAZ0pyEX8aM5wtyQLWlPXmI5ZNM5hXFjLrw=\n=l4pk\n-----END PGP SIGNATURE-----"
    ],
    parent => [
      "21a06f684ba48bdff19436074f991267c849afcf",
      "7fa20ca61711a0109d431b1a479e3091c8ac9317"
    ],
    subject => "dobr\303\275 den (cs)",
    tree => "7b8f01341e59251bbf067b1001cdd12f44c36847"
  },
  "60e4317e8c82fe9cc14058a5cd82ae95da4160d3" => {
    body => "",
    extra => "",
    gpgsig => "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQDfooH/2lWSRzo93o9kEnRMo4qqjtC\nbVAQOOCXr6ZuqFGSMnqoc6Am8nz8lhf379aA3iwmDrbUuDfGb71CsajUa7hvYsTm\nPd65arkNW+iXQgqpXgop0z9sAeLC9NvzT3IxWaZK63HYzXLd/z2u55OOA3mpimJE\nidbMBiQH6EKs+x9BT7CZ8D03oiGnaGCVfmyB3Iu7Pdf+vtLER5D3JUaGWijtIPWS\nSara2Lc28CWrn6SnEdUaLX95nOGWA/cwmCILoVgrArECQSnb1XQTL47M7UX6P7Lb\nKuC4ASpofSYYlUmdGRQa6YX2Sdq1RPGB0fd5hMcUN0ChrcMPHeeRu9sIn0764xs=\n=hpCM\n-----END PGP SIGNATURE-----",
    mergetag => [
      "object be8bb3e4c13f7c7b01d635d86999a87c8b6d87aa\ntype commit\ntag v1.0.3\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQDKEgH/0H9PFgB6naV/hbHf9gASwdg\nPsBBhe6eIAyqorFWqibbhiq14C19KPWOAuK3y4PvYyVGCiSqA+EMShV09JnS8KLe\nfxrPgDfqWwMCmDpuy6xY8wZILlWxtdwMtJt5/Cc1anAkVBx0TrCwx500UYJdPuMK\nEUHPBWNrjzIF2IKhnZRrxaKXEDLvWytVIy5vUBPDrJwdEYDKZbVNSQgTPLVpJW8D\nj5iSC8h+9Jc4y0Hrs3mZ1FRngD+EVOUmQzxRk+UVyT4QkpI50BLoX0i56eoiMWM0\nZY1nEam29yRVZr/E7QOLiWnXrHyzMwYqTXAwnRtp4BFBN02g1oJzeylB/VpUOQg=\n=vxO9\n-----END PGP SIGNATURE-----"
    ],
    parent => [
      "998cab1c95332c2967dc44b41425661af9c8dcbd",
      "be8bb3e4c13f7c7b01d635d86999a87c8b6d87aa"
    ],
    subject => "buen d\303\255a (es)",
    tree => "7b8f01341e59251bbf067b1001cdd12f44c36847"
  },
  "6c23b41b247ce53abb5bfa06beaba8ec33eb1a3f" => {
    body => "# tag 'v1.1.0'\nsigned tag\n\n# gpg: Signature made Tue Nov  5 06:32:39 2013 CET using RSA key ID 7621C403\n# gpg: Good signature from \"Example Author <author\@example.com>\"\n\n# tag 'v1.0.1'\n\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257\n\n# gpg: Signature made Tue Nov  5 06:32:38 2013 CET using RSA key ID 7621C403\n# gpg: Good signature from \"Example Author <author\@example.com>\"\n",
    extra => "",
    mergetag => [
      "object 21a06f684ba48bdff19436074f991267c849afcf\ntype commit\ntag v1.1.0\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQDq4AH/jwSqR2olbhr6gNZJPcbWEXV\np/OtrMgB+O8KRWL0At8a9VTbehLeSnRE36WpLgyUVAHpMDw+OB0A1rpS+Ajz/3N/\ntwbPHbO7xIflBZ9TotigGybV2gUpZkFQW9EpQBCpP+ZqLN8vviWogcxCsU2lnmdx\nc6UeBS/pU7TV08WltFuL7WsoA0oIypFD1Yj9nmAtSdlnn0fTlt8YC0h1mrMWWIaN\nBYejxlFQBL7nwg7pxHJl89UtXYiEMJN950skLyq4YX5qLvD1OIxdRtPfIPNLo1sC\n//WCSBGHyhzCP8YSgKFd2Ho0tvxxvR3nEmmrLktSIZmM7AhPuco7dUsakSYyXLA=\n=eqmq\n-----END PGP SIGNATURE-----",
      "object 7fa20ca61711a0109d431b1a479e3091c8ac9317\ntype commit\ntag v1.0.1\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\n\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL2AAoJEOX2RRt2IcQDVAcH/2gaHSXfEgOuvB5S66JWNTMT\n4rqAJkFzaWUgT8F/ofou5O958n5bTjla1YHn93Cm+JCrJk53ECZR1lH0u8H5tRQK\nAQbKO/5HCHh9vh8/G4gghL62a8BwBU5wGwujZdFjtJOmix/2/80QuP5dY7zB1p2j\n0g024ZOaDvv70YAbFQibzZNH/I4LQK0gB2NamVZmcrWI/YWH8LVdVJrzkGFMne/r\n5F5B+kOXZp7KDCdbToNMT2NG5KAT6nkyCWv6njcehiL85V73hpBLy/HD1FAHeGFD\nzru/CXmrEejKRXoz8F7QBx8z2uQ4PAZ0pyEX8aM5wtyQLWlPXmI5ZNM5hXFjLrw=\n=l4pk\n-----END PGP SIGNATURE-----"
    ],
    parent => [
      "0ae36f101c68fd82a5bb9845fdf99e3fc6ab369e",
      "21a06f684ba48bdff19436074f991267c849afcf",
      "7fa20ca61711a0109d431b1a479e3091c8ac9317"
    ],
    subject => "Merge tags 'v1.1.0' and 'v1.0.1' into mergetags",
    tree => "fa85af1dc631f3f8d977aafe0253b1d02eb2c4c7"
  },
  "7fa20ca61711a0109d431b1a479e3091c8ac9317" => {
    body => "",
    extra => "",
    parent => [
      "f7c18a39ec24778012af208988bc23e6f1f3a636"
    ],
    subject => "\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257 (ja)",
    tree => "822aed1f11e71b48d14c899d209b0dca92a08ec8"
  },
  "88df96b38e9861eab3af30a312d24a740f3defd2" => {
    body => "",
    extra => "",
    parent => [],
    subject => "empty tree",
    tree => "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
  },
  "998cab1c95332c2967dc44b41425661af9c8dcbd" => {
    body => "",
    extra => "",
    gpgsig => "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQD+rAH/1Z17+KdH6luVOkOWk1Xcoga\nWFHji9++oBDE6MeydFWfY3PPFDXYjcbnJEkFtTp1F5hzuRqyGGJVnPHAxp7dVDSO\njQ4WZBnfNYA4wyI0U+TuvrPOHUKSvdHuhleE33knLT4q6xxbIm+v8OcptXfx1x7m\ni3/MGYDuUALPg7HbwLHxDh9d8S69c9cyAm3TLQO4IcWWKSI278siIHD9Ex856XKB\nLDsvb5Xy704LM505HqamMozuFMooJz2KHPUoYm0zdBh85nQL+xFvwfDjpVsxsqxf\n5Y3gI+3mHs1twnynMdOIu0Lt4d2EY/hDUwmbdIgYvd+3KhxFOZpOwwZNbC2rykk=\n=UtOD\n-----END PGP SIGNATURE-----",
    mergetag => [
      "object d47252b6857d8f8d5cbb531a5240358293d56e7e\ntype commit\ntag v1.0.2\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQDsv4H/2uqrlUHDAmDfe3Dy3uysJEo\nSb9GVXI6G9GdCn5ZBKAXK83bjMTkRtI0viAXXUwCsga0AeKvysvhguDgFU2GLBxQ\n52K3mDlt0pKlSEEObTM1oRs7xE7B2c6SQ30JTfKCrN75H9Rldp6aCVaij1uDU8b5\nvKL5MprHmGfEgEUda0KJnandyGWaGKTovzKhnEooskMT/iyiNmjrohmIMarYiYoB\nzS+Ejo3BzAKRUij9+8j+SFRlFusIjBCBUUddmYgbWxQiDZqFn/vjrvQsUtlCKAsK\nTh+772Dq5G2aHgrAO8uBIJ6AddOJGBd2FjLClv24HrSllHufpCO8uEawbLh/NmM=\n=qrsZ\n-----END PGP SIGNATURE-----"
    ],
    parent => [
      "3eee6394377f62106ddd207b68942676da1b18ea",
      "d47252b6857d8f8d5cbb531a5240358293d56e7e"
    ],
    subject => "bom dia",
    tree => "7b8f01341e59251bbf067b1001cdd12f44c36847"
  },
  "9be9b53c65ebf7c4f9d6de843619fd0990fb8d43" => {
    body => "",
    extra => "",
    parent => [],
    subject => "hello (en)",
    tree => "fa85af1dc631f3f8d977aafe0253b1d02eb2c4c7"
  },
  "9fe2fecbe3ffef3c66ba4f5cc43f716f6cc751d3" => {
    body => "",
    extra => "",
    parent => [
      "0ae36f101c68fd82a5bb9845fdf99e3fc6ab369e"
    ],
    subject => "g\303\263\303\260ur dagur (is)",
    tree => "b090e309a779f2ea76260d10abd027b08fb36362"
  },
  a284f510c8400eb59759afc725162214033096b1 => {
    body => "",
    extra => "",
    gpgsig => "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL4AAoJEOX2RRt2IcQD040H/3JzRf7Pxxcre3FG54FtI4IP\necNQetBwnedCLaBqSqez9I/Cr+3OWnYjwLL/0pviU16S+ziM0naEa9jkBdvSxOo1\nuJA+1QlSnioLJG6+tH7YqV260ElDFhjTHcAX8xXO1jAWsI4OfSkYll8cGYd1joQG\n5Uw39RVpcElAfbWCDNE4tl2BrBk3LHC2xnPxCkUOi1h4dxWjD1Obz6JIDUlwdZ5R\n9JndRYu4kBVdXDU+NPnIvPMzEFVcCf0ncGwc1KsHKRaTt1KILk5s68wOj6amd9/J\nVpE9JNemKQTHEtOLFoAunweGBlUgROyMNnLz91Ld8+WEOAzMr4dWgTgPylRNfI4=\n=WF0v\n-----END PGP SIGNATURE-----",
    mergetag => [
      "object 21a06f684ba48bdff19436074f991267c849afcf\ntype commit\ntag v1.1.0\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQDq4AH/jwSqR2olbhr6gNZJPcbWEXV\np/OtrMgB+O8KRWL0At8a9VTbehLeSnRE36WpLgyUVAHpMDw+OB0A1rpS+Ajz/3N/\ntwbPHbO7xIflBZ9TotigGybV2gUpZkFQW9EpQBCpP+ZqLN8vviWogcxCsU2lnmdx\nc6UeBS/pU7TV08WltFuL7WsoA0oIypFD1Yj9nmAtSdlnn0fTlt8YC0h1mrMWWIaN\nBYejxlFQBL7nwg7pxHJl89UtXYiEMJN950skLyq4YX5qLvD1OIxdRtPfIPNLo1sC\n//WCSBGHyhzCP8YSgKFd2Ho0tvxxvR3nEmmrLktSIZmM7AhPuco7dUsakSYyXLA=\n=eqmq\n-----END PGP SIGNATURE-----",
      "object d47252b6857d8f8d5cbb531a5240358293d56e7e\ntype commit\ntag v1.0.2\ntagger Example Committer <committer\@example.com> 1383629558 +0100\n\nsigned tag\n-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL3AAoJEOX2RRt2IcQDsv4H/2uqrlUHDAmDfe3Dy3uysJEo\nSb9GVXI6G9GdCn5ZBKAXK83bjMTkRtI0viAXXUwCsga0AeKvysvhguDgFU2GLBxQ\n52K3mDlt0pKlSEEObTM1oRs7xE7B2c6SQ30JTfKCrN75H9Rldp6aCVaij1uDU8b5\nvKL5MprHmGfEgEUda0KJnandyGWaGKTovzKhnEooskMT/iyiNmjrohmIMarYiYoB\nzS+Ejo3BzAKRUij9+8j+SFRlFusIjBCBUUddmYgbWxQiDZqFn/vjrvQsUtlCKAsK\nTh+772Dq5G2aHgrAO8uBIJ6AddOJGBd2FjLClv24HrSllHufpCO8uEawbLh/NmM=\n=qrsZ\n-----END PGP SIGNATURE-----"
    ],
    parent => [
      "88df96b38e9861eab3af30a312d24a740f3defd2",
      "21a06f684ba48bdff19436074f991267c849afcf",
      "d47252b6857d8f8d5cbb531a5240358293d56e7e"
    ],
    subject => "buon giorno (it)",
    tree => "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
  },
  a8516d977b481a4d73dda9b75cad4bfe71012e81 => {
    body => "",
    extra => "",
    parent => [
      "60e4317e8c82fe9cc14058a5cd82ae95da4160d3"
    ],
    subject => "add the README",
    tree => "3096e79fddf5e2f440df8401af0c478a683d9071"
  },
  b9998a8d2c194fd5f64440dbb381ef54921b4a4a => {
    body => "",
    extra => "",
    parent => [
      "0ae36f101c68fd82a5bb9845fdf99e3fc6ab369e"
    ],
    subject => "\343\201\223\343\202\223\343\201\253\343\201\241\343\201\257 (ja)",
    tree => "51827db31da3d816058b613f19c971e5c4fa6f16"
  },
  be8bb3e4c13f7c7b01d635d86999a87c8b6d87aa => {
    body => "",
    extra => "",
    parent => [
      "d47252b6857d8f8d5cbb531a5240358293d56e7e"
    ],
    subject => "",
    tree => "524a684865d9b37e0a7236df14ccde01501f063d"
  },
  d47252b6857d8f8d5cbb531a5240358293d56e7e => {
    body => "",
    extra => "",
    gpgsig => "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL2AAoJEOX2RRt2IcQDErUIAIMAep/ltBrsqZ5Aoe9ByeN6\npF2qaISdQ7ygxuLBVnUCwzMjsSKC6H8l1z5NgWNr6zQy1dJ4c/oJsjqvp5AfC52L\nO024cSX0ahQbsaCz9NBEIYdrzgT3tLMzgp82jr8ZKvzAWI7TyoqJJ6L7NFOAHQXt\nkPuDbf1ll5f40A/Tvk12e6vD0yNCe8o5ihjJ93uep2FBfbb2K4QOcFzE0FIhCmoS\nhg0hZveE42W+j34d8DLzHwzVvGBh+sBIjRqBg0I8pc6/CzajngvCToWQAzYSJZr6\neY3w+5cXHwbPGELujrCk9xien8DF3H8ETC/49g2oncnEWssY/ROQ0Yn4PALDu/c=\n=BLwa\n-----END PGP SIGNATURE-----",
    parent => [
      "7fa20ca61711a0109d431b1a479e3091c8ac9317"
    ],
    subject => "ol\303\241 (pt)",
    tree => "33a90fc1da2f84bfc394fa886a3d70ae534dc03f"
  },
  dd8437af8d1fa7c53de33db969ceceee8c1c153a => {
    body => "",
    extra => "",
    gpgsig => "-----BEGIN PGP SIGNATURE-----\nVersion: GnuPG v1.4.12 (GNU/Linux)\n\niQEcBAABAgAGBQJSeIL2AAoJEOX2RRt2IcQDITcH/02I4nMpkkZDkveN6W2FS+We\nEZGu/kukFNxsp/Q8SucicaNfsYJRdU9MNrakxufJOQN7WPTkRYlEG3DIRwJHpP0N\nAlz0zavY/J0qDAkgsmiF0OIie44ecpp+ghckCkFyijESda5RArMWxiaikFoBOpgP\nHYvkkzbv9NZvTxNvZF+eWoJFbxBE3N/2vNiADcrJ6gUdBQVQHj4d364lPEb/ZnIj\nH4XwcqA76NYL+0F09bAkx7BS0S3/alYyPe+SFok6xCL62dj7Yv4ocJtA5eDVFA/n\naNiEGTf1is8C2d2irJNt8+420pXOzGAtLaTaHXkMlpDD4MLxdIVxI6eTZXdOLCY=\n=1pdD\n-----END PGP SIGNATURE-----",
    parent => [
      "b9998a8d2c194fd5f64440dbb381ef54921b4a4a"
    ],
    subject => "hej (da)",
    tree => "7b8f01341e59251bbf067b1001cdd12f44c36847"
  },
  f7c18a39ec24778012af208988bc23e6f1f3a636 => {
    body => "",
    extra => "",
    parent => [
      "9fe2fecbe3ffef3c66ba4f5cc43f716f6cc751d3"
    ],
    subject => "hall\303\263 (is)",
    tree => "1840015fc84bf133760c966eed4c1b4047ea657a"
  }
);
